==> ngx-progressbar-11.1.0.tgz: package/README.md <==
<p align="center">
  <img height="200px" width="200px" style="text-align: center;" src="https://gitcdn.xyz/repo/MurhafSousli/ngx-progressbar/master/projects/ngx-progressbar-demo/src/assets/logo.svg">
  <h1 align="center">Angular Progressbar</h1>
</p>

[![npm](https://img.shields.io/badge/demo-online-ed1c46.svg)](https://ngx-progressbar.netlify.com/)
[![npm](https://img.shields.io/badge/stackblitz-online-orange.svg)](https://stackblitz.com/edit/ngx-progressbar)
[![npm](https://img.shields.io/npm/v/ngx-progressbar.svg?maxAge=2592000?style=plastic)](https://www.npmjs.com/package/ngx-progressbar)
[![tests](https://github.com/MurhafSousli/ngx-progressbar/workflows/tests/badge.svg)](https://github.com/MurhafSousli/ngx-progressbar/actions?query=workflow%3Atests)
[![npm](https://img.shields.io/npm/dt/ngx-progressbar.svg?maxAge=2592000?style=plastic)](https://www.npmjs.com/package/ngx-progressbar)
[![npm](https://img.shields.io/npm/dm/ngx-progressbar.svg)](https://www.npmjs.com/package/ngx-progressbar)
[![npm bundle size (minified + gzip)](https://img.shields.io/bundlephobia/minzip/ngx-progressbar.svg)](https://bundlephobia.com/result?p=ngx-progressbar)
[![npm](https://img.shields.io/npm/l/express.svg?maxAge=2592000)](https://github.com/MurhafSousli/ngx-progressbar/blob/master/LICENSE)

A nanoscopic progress bar. Featuring realistic trickle animations to convince your users that something is happening!

___

### The documentation is available at the [wiki page](https://github.com/MurhafSousli/ngx-progressbar/wiki) 📚

___

## Issues

If you identify any errors in the library, or have an idea for an improvement, please open an [issue](https://github.com/MurhafSousli/ngx-progressbar/issues).

## Sponsoring ngx-progressbar

[![Backers on Open Collective](https://opencollective.com/ngx-progressbar/tiers/backers/badge.svg?label=Backers&color=brightgreen)](#sponsoring-ngx-progressbar)

### Sponsors

Become a sponsor and get your logo on our README on GitHub and the front page of [https://ngx-progressbar.netlify.com/](https://ngx-progressbar.netlify.com/).

[![Sponsors on Open Collective](https://opencollective.com/ngx-progressbar/tiers/sponsors.svg?avatarHeight=64)](https://opencollective.com/ngx-progressbar/contribute/sponsors-11015/checkout)

### Backers

Become a backer and get your logo on our README on GitHub.

[![Backers on Open Collective](https://opencollective.com/ngx-progressbar/tiers/backers.svg?avatarHeight=64)](https://opencollective.com/ngx-progressbar/contribute/backers-11014/checkout)

## Author

**Murhaf Sousli**

- [github/murhafsousli](https://github.com/MurhafSousli)
- [twitter/murhafsousli](https://twitter.com/MurhafSousli)

==> ngx-progressbar-14.0.0.tgz: package/README.md <==
<p align="center">
  <img height="200px" width="200px" style="text-align: center;" src="https://rawcdn.githack.com/MurhafSousli/ngx-progressbar/e5f30ba33c83690da3249ef2a665e6168b8caeb1/projects/ngx-progressbar-demo/src/assets/logo.svg">
  <h1 align="center">Angular Progressbar</h1>
</p>

[![demo](https://img.shields.io/badge/demo-online-ed1c46.svg)](https://ngx-progressbar.netlify.app/)
[![npm](https://img.shields.io/badge/stackblitz-online-orange.svg)](https://stackblitz.com/edit/ngx-progressbar)
[![npm](https://img.shields.io/npm/v/ngx-progressbar.svg?maxAge=2592000?style=plastic)](https://www.npmjs.com/package/ngx-progressbar)
[![tests](https://github.com/MurhafSousli/ngx-progressbar/workflows/tests/badge.svg)](https://github.com/MurhafSousli/ngx-progressbar/actions?query=workflow%3Atests)
[![codecov](https://codecov.io/gh/MurhafSousli/ngx-progressbar/graph/badge.svg?token=hIKXnJRikz)](https://codecov.io/gh/MurhafSousli/ngx-progressbar)
[![npm](https://img.shields.io/npm/dt/ngx-progressbar.svg?maxAge=2592000?style=plastic)](https://www.npmjs.com/package/ngx-progressbar)
[![npm](https://img.shields.io/npm/dm/ngx-progressbar.svg)](https://www.npmjs.com/package/ngx-progressbar)
[![npm bundle size (minified + gzip)](https://img.shields.io/bundlephobia/minzip/ngx-progressbar.svg)](https://bundlephobia.com/result?p=ngx-progressbar)
[![npm](https://img.shields.io/npm/l/express.svg?maxAge=2592000)](https://github.com/MurhafSousli/ngx-progressbar/blob/master/LICENSE)

A nanoscopic progress bar. Featuring realistic trickle animations to convince your users that something is happening!

___

## Documentations

### Table of contents

* [Usage](docs/Usage.md)
* [Styling](docs/Styling.md)
* [Global Options](docs/Global-options.md)
* [Smooth Scroll Functions](docs/Integration.md)
* Automagic features
  * [HttpClient Requests](docs/HttpClient-requests.md)
  * [Router Events](docs/Router-events.md)

___

## Issues

If you identify any errors in the library, or have an idea for an improvement, please open an [issue](https://github.com/MurhafSousli/ngx-progressbar/issues).

## Author

**Murhaf Sousli**

- [github/murhafsousli](https://github.com/MurhafSousli)
- [twitter/murhafsousli](https://twitter.com/MurhafSousli)
